@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "No definit",
     "Denied (Inherited permission)" : "Denegat (permís heretat)",
     "Allowed (Inherited permission)" : "Permès (permís heretat)",
     "Denied" : "Denegat",
@@ -19,7 +18,6 @@ OC.L10N.register(
     "Share" : "Comparteix",
     "You" : "Vós",
     "Remove access rule" : "Suprimeix la regla d'accés",
-    "Add advanced permission rule" : "Afegeix una regla de permisos avançada",
     "Select a user or group" : "Seleccioneu un usuari o un grup",
     "Add group" : "Afegeix un grup",
     "Default" : "Per defecte",
@@ -33,6 +31,7 @@ OC.L10N.register(
     "User" : "Usuari",
     "Unknown" : "Desconegut",
     "None" : "Només una vegada",
-    "{size} used" : "{size} en ús"
+    "{size} used" : "{size} en ús",
+    "Unset" : "No definit"
 },
 "nplurals=2; plural=(n != 1);");
