@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "Desestablecer",
     "Denied (Inherited permission)" : "Denegado (permiso heredado)",
     "Allowed (Inherited permission)" : "Permitido (permiso heredado)",
     "Denied" : "Denegado",
@@ -20,7 +19,6 @@ OC.L10N.register(
     "Share" : "Compartir",
     "You" : "Tú",
     "Remove access rule" : "Eliminar regla de acceso",
-    "Add advanced permission rule" : "Añadir regla de permisos avanzados",
     "Select a user or group" : "Seleccionar un usuario o grupo",
     "Permission denied. User does not have sufficient permissions." : "Permiso denegado. El usuario no cuenta con los permisos suficientes.",
     "Unexpected status from server" : "Estado inesperado del servidor",
@@ -38,6 +36,7 @@ OC.L10N.register(
     "Unknown" : "Desconocido",
     "None" : "Ninguno",
     "{size} used" : "{size} usado",
-    "Other …" : "Otro ..."
+    "Other …" : "Otro ...",
+    "Unset" : "Desestablecer"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
