@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "You cannot remove your own read permission." : "Et voi poistaa omaa lukuoikeuttasi.",
     "Team folders" : "Tiimikansiot",
-    "Unset" : "Poista",
+    "Team Folders" : "Tiimikansiot",
     "Denied (Inherited permission)" : "Estetty (peritty oikeus)",
     "Allowed (Inherited permission)" : "Sallittu (peritty oikeus)",
     "Denied" : "Estetty",
@@ -15,6 +15,7 @@ OC.L10N.register(
     "Allow" : "Salli",
     "Group" : "Ryhmä",
     "Team" : "Tiimi",
+    "Advanced permissions for Team folder" : "Tiimikansion edistyneet oikeudet",
     "Team folder" : "Tiimikansio",
     "Read" : "Lue",
     "Write" : "Kirjoita",
@@ -23,7 +24,7 @@ OC.L10N.register(
     "Share" : "Jako",
     "You" : "Sinä",
     "Remove access rule" : "Poista käyttösääntö",
-    "Add advanced permission rule" : "Lisää edistynyt käyttösääntö",
+    "Add new rule" : "Lisää uusi sääntö",
     "Select a user or group" : "Valitse käyttäjä tai ryhmä",
     "Open Team folder" : "Avaa tiimikansio",
     "Permission denied. User does not have sufficient permissions." : "Pääsy estetty. Käyttäjällä ei ole riittävästi oikeuksia.",
@@ -51,6 +52,7 @@ OC.L10N.register(
     "{displayName} (team)" : "{displayName} (tiimi)",
     "Add group or team" : "Lisää ryhmä tai tiimi",
     "{size} used" : "{size} käytetty",
-    "Other …" : "Muu…"
+    "Other …" : "Muu…",
+    "Unset" : "Poista"
 },
 "nplurals=2; plural=(n != 1);");
