@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "ביטול הגדרה",
     "Denied (Inherited permission)" : "חסום (הרשאה בירושה)",
     "Allowed (Inherited permission)" : "מורשה (הרשאה בירושה)",
     "Denied" : "חסום",
@@ -18,7 +17,6 @@ OC.L10N.register(
     "Share" : "שיתוף",
     "You" : "אני",
     "Remove access rule" : "הסרת כלל גישה",
-    "Add advanced permission rule" : "הוספת כלל הרשאות מתקדמות",
     "Select a user or group" : "נא לבחור משתמש או קבוצה",
     "Add group" : "הוספת קבוצה",
     "Default" : "ברירת מחדל",
@@ -31,6 +29,7 @@ OC.L10N.register(
     "User" : "משתמש",
     "Unknown" : "לא ידוע",
     "None" : "ללא",
-    "{size} used" : "{size} בשימוש"
+    "{size} used" : "{size} בשימוש",
+    "Unset" : "ביטול הגדרה"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
