@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "Kikapcsolás",
     "Denied (Inherited permission)" : "Tiltott (örökölt jogosultság)",
     "Allowed (Inherited permission)" : "Engedélyezett (örökölt jogosultság)",
     "Denied" : "Tiltott",
@@ -20,7 +19,6 @@ OC.L10N.register(
     "Share" : "Megosztás",
     "You" : "Ön",
     "Remove access rule" : "Hozzáférési szabály eltávolítása",
-    "Add advanced permission rule" : "Speciális jogosultsági szabály hozzáadása",
     "Select a user or group" : "Válasszon ki egy felhasználót vagy csoportot",
     "Permission denied. User does not have sufficient permissions." : "Engedély megtagadva. A felhasználó nem rendelkezik elegendő jogosultsággal.",
     "Unexpected status from server" : "Váratlan állapot a kiszolgálótól",
@@ -43,6 +41,7 @@ OC.L10N.register(
     "No other groups available" : "Nincs másik elérhető csoport",
     "{displayName} (team)" : "{displayName} (csapat)",
     "Add group or team" : "Csoport vagy csapat hozzáadása",
-    "{size} used" : "{size} felhasználva"
+    "{size} used" : "{size} felhasználva",
+    "Unset" : "Kikapcsolás"
 },
 "nplurals=2; plural=(n != 1);");
