@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "Endurstilla",
     "Denied (Inherited permission)" : "Hafnað (erfðar heimildir)",
     "Allowed (Inherited permission)" : "Leyft (erfðar heimildir)",
     "Denied" : "Hafnað",
@@ -19,7 +18,6 @@ OC.L10N.register(
     "Share" : "Deila",
     "You" : "Þú",
     "Remove access rule" : "Fjarlægja aðgangsreglu",
-    "Add advanced permission rule" : "Bæta við ítarlegri heimildareglu",
     "Select a user or group" : "Veldu notanda eða hóp",
     "Add group" : "Bæta við hópi",
     "Default" : "Sjálfgefið",
@@ -34,6 +32,7 @@ OC.L10N.register(
     "Unknown" : "Óþekkt",
     "None" : "Ekkert",
     "{size} used" : "{size} notað",
-    "Other …" : "Annað …"
+    "Other …" : "Annað …",
+    "Unset" : "Endurstilla"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
