@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "설정 해제",
     "Denied (Inherited permission)" : "거부됨(권한 상속)",
     "Allowed (Inherited permission)" : "허용됨(권한 상속)",
     "Denied" : "거부됨",
@@ -18,7 +17,6 @@ OC.L10N.register(
     "Share" : "공유",
     "You" : "나",
     "Remove access rule" : "접근 규칙 삭제",
-    "Add advanced permission rule" : "고급 권한 규칙 추가",
     "Select a user or group" : "사용자 또는 그룹 선택",
     "Add group" : "그룹 추가",
     "Default" : "디폴트",
@@ -31,6 +29,7 @@ OC.L10N.register(
     "User" : "사용자",
     "Unknown" : "알 수 없음",
     "None" : "없음",
-    "{size} used" : "{size} 사용됨"
+    "{size} used" : "{size} 사용됨",
+    "Unset" : "설정 해제"
 },
 "nplurals=1; plural=0;");
