@@ -2,7 +2,6 @@ OC.L10N.register(
     "groupfolders",
     {
     "Team folders" : "Тимски папки",
-    "Unset" : "Непоставено",
     "Denied (Inherited permission)" : "Забрането (наследена дозвола)",
     "Allowed (Inherited permission)" : "Овозможено (наследена дозвола)",
     "Denied" : "Забрането",
@@ -22,7 +21,6 @@ OC.L10N.register(
     "Share" : "Сподели",
     "You" : "Ти",
     "Remove access rule" : "Отстрани правило за пристап",
-    "Add advanced permission rule" : "Додај напредно правило за дозвола",
     "Select a user or group" : "Избери корисник или група",
     "Open Team folder" : "Отвори тимска папка",
     "List of Team folders." : "Листа на тимски папки.",
@@ -41,6 +39,7 @@ OC.L10N.register(
     "User" : "Корисник",
     "Unknown" : "Непознат",
     "None" : "Ништо",
-    "{size} used" : "искористено {size}"
+    "{size} used" : "искористено {size}",
+    "Unset" : "Непоставено"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
