@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "Ikke satt",
     "Denied (Inherited permission)" : "Nektet (arvet rettighet)",
     "Allowed (Inherited permission)" : "Tillatt (arvet rettighet)",
     "Denied" : "Nektet",
@@ -20,7 +19,6 @@ OC.L10N.register(
     "Share" : "Del",
     "You" : "Du",
     "Remove access rule" : "Fjern tilgangsregel",
-    "Add advanced permission rule" : "Legg til avansert rettighetsregel",
     "Select a user or group" : "Velg en bruker eller gruppe",
     "Permission denied. User does not have sufficient permissions." : "Tillatelse nektet. Brukeren har ikke tilstrekkelige tillatelser.",
     "Unexpected status from server" : "Uventet status fra server",
@@ -39,6 +37,7 @@ OC.L10N.register(
     "Unknown" : "Ukjent",
     "None" : "Ingen",
     "{size} used" : "{size} brukt",
-    "Other …" : "Annet…"
+    "Other …" : "Annet…",
+    "Unset" : "Ikke satt"
 },
 "nplurals=2; plural=(n != 1);");
