@@ -2,7 +2,6 @@ OC.L10N.register(
     "groupfolders",
     {
     "Team folders" : "Teammappen",
-    "Unset" : "Schakel uit",
     "Denied (Inherited permission)" : "Geweigerd (Overgeërfde machtiging)",
     "Allowed (Inherited permission)" : "Toegelaten (Overgeërfde machtiging)",
     "Denied" : "Geweigerd",
@@ -20,7 +19,6 @@ OC.L10N.register(
     "Share" : "Delen",
     "You" : "Jij",
     "Remove access rule" : "Verwijder toegangsregel",
-    "Add advanced permission rule" : "Voeg een geavanceerde machtiging toe",
     "Select a user or group" : "Kies een gebruiker of groep",
     "No Team folders yet" : "Nog geen teammappen",
     "Team folders will show up here" : "Teammappen worden hier getoond",
@@ -38,6 +36,7 @@ OC.L10N.register(
     "Unknown" : "Onbekend",
     "None" : "Geen",
     "{size} used" : "{size} gebruikt",
-    "Other …" : "Overig..."
+    "Other …" : "Overig...",
+    "Unset" : "Schakel uit"
 },
 "nplurals=2; plural=(n != 1);");
