@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "Desetează",
     "Access denied" : "Acces interzis",
     "Deny" : "Refuzați",
     "Allow" : "Permiteți",
@@ -22,6 +21,7 @@ OC.L10N.register(
     "User" : "Utilizator",
     "Unknown" : "Necunoscut",
     "None" : "Niciuna",
-    "{size} used" : "{size} folosită"
+    "{size} used" : "{size} folosită",
+    "Unset" : "Desetează"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
