@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "Non cunfiguradu",
     "Denied (Inherited permission)" : "Negadu (permissu eredadu)",
     "Allowed (Inherited permission)" : "Cunsentidu (permissu eredadu)",
     "Denied" : "Negadu",
@@ -17,7 +16,6 @@ OC.L10N.register(
     "Share" : "Cumpartzidura",
     "You" : "Tue",
     "Remove access rule" : "Boga·nche règula de intrada",
-    "Add advanced permission rule" : "Agiunghe règula de permissu avantzada",
     "Select a user or group" : "Seletziona un'utente o grupu",
     "Add group" : "Agiunghe grupu",
     "Default" : "Predefinidu",
@@ -31,6 +29,7 @@ OC.L10N.register(
     "User" : "Utente",
     "Unknown" : "Disconnotu",
     "None" : "Perunu",
-    "{size} used" : "{size} impreadu"
+    "{size} used" : "{size} impreadu",
+    "Unset" : "Non cunfiguradu"
 },
 "nplurals=2; plural=(n != 1);");
