@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "Ukloni",
     "Deny" : "Odbij",
     "Allow" : "Dozvoli",
     "Group" : "Group",
@@ -12,6 +11,7 @@ OC.L10N.register(
     "Folder name" : "Naziv fascikle",
     "User" : "Korisnik",
     "None" : "Ništa",
-    "{size} used" : "{size} iskorišćeno"
+    "{size} used" : "{size} iskorišćeno",
+    "Unset" : "Ukloni"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
