@@ -1,7 +1,6 @@
 OC.L10N.register(
     "groupfolders",
     {
-    "Unset" : "Bỏ cài đặt",
     "Deny" : "Từ chối",
     "Allow" : "Cho phép",
     "Group" : "Nhóm",
@@ -20,6 +19,7 @@ OC.L10N.register(
     "User" : "Người dùng",
     "Unknown" : "Không xác định",
     "None" : "Không có",
-    "{size} used" : "{size} đã sử dụng"
+    "{size} used" : "{size} đã sử dụng",
+    "Unset" : "Bỏ cài đặt"
 },
 "nplurals=1; plural=0;");
