@@ -7,6 +7,7 @@ declare(strict_types=1);
  */
 namespace OCA\GroupFolders;
 
+use OC\Files\Storage\Wrapper\Jail;
 use OCA\GroupFolders\Mount\GroupFolderStorage;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Files\Cache\CacheEntryInsertedEvent;
@@ -15,7 +16,7 @@ use OCP\Files\Cache\ICacheEvent;
 
 class CacheListener {
 	public function __construct(
-		private IEventDispatcher $eventDispatcher,
+		private readonly IEventDispatcher $eventDispatcher,
 	) {
 	}
 
@@ -25,13 +26,15 @@ class CacheListener {
 	}
 
 	public function onCacheEvent(ICacheEvent $event): void {
-		if (!$event->getStorage()->instanceOfStorage(GroupFolderStorage::class)) {
+		$storage = $event->getStorage();
+		if (!$storage->instanceOfStorage(GroupFolderStorage::class)) {
 			return;
 		}
-
-		$jailedPath = preg_replace('/^__groupfolders\/\d+\//', '', $event->getPath());
-		if ($jailedPath !== $event->getPath()) {
-			$event->setPath($jailedPath);
+		if (!$storage->instanceOfStorage(Jail::class)) {
+			return;
+		}
+		if ($path = $storage->getJailedPath($event->getPath())) {
+			$event->setPath($path);
 		}
 	}
 }
