@@ -1,5 +1,6 @@
 <?php
 
+declare (strict_types=1);
 /**
  * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -16,8 +17,8 @@ use OCP\IUserSession;
  */
 class FoldersFilter {
 	public function __construct(
-		private IUserSession $userSession,
-		private IGroupManager $groupManager,
+		private readonly IUserSession $userSession,
+		private readonly IGroupManager $groupManager,
 	) {
 	}
 
